@@ -1,4 +1,5 @@
 import abc
+import builtins
 import datetime
 import enum
 import typing
@@ -7,9 +8,8 @@ import jsii
 import jsii.compat
 import publication
 
-from jsii.python import classproperty
-
 import aws_cdk.aws_iam
+import aws_cdk.aws_kms
 import aws_cdk.core
 import aws_cdk.cx_api
 __all__ = []
